# Flask-UIO

Flask-UIO is a package for building user interface as object.

**Supported:** 

- [Fomantic-UI](https://fomantic-ui.com/)


Installing
==========

Install and update using [pip](https://pip.pypa.io/en/stable/quickstart/):

```bash
pip install flask-uio
```

Links:
======

- [Documentation)](https://flask-uio.readthedocs.io/en/latest/index.html)